@@ -1,6 +1,5 @@
 #' @title Message about bootstrapped confidence intervals for effect sizes.
 #' @name effsize_ci_message
-#' @author \href{https://github.com/IndrajeetPatil}{Indrajeet Patil}
 #'
 #' @inheritParams t1way_ci
 #'
@@ -33,16 +32,3 @@ effsize_type_switch <- function(effsize.type) {
     TRUE ~ "unbiased"
   )
 }
-
-
-#' @noRd
-
-stats_type_switch <- function(type) {
-  dplyr::case_when(
-    grepl("^p", type, TRUE) ~ "parametric",
-    grepl("^n|^s", type, TRUE) ~ "nonparametric",
-    grepl("^r", type, TRUE) ~ "robust",
-    grepl("^b", type, TRUE) ~ "bayes",
-    TRUE ~ "parametric"
-  )
-}
