@@ -1,20 +1,18 @@
 #' @title Making expression containing *t*-test results
 #' @name expr_t_parametric
-#' @author \href{https://github.com/IndrajeetPatil}{Indrajeet Patil}, Chuck Powell
 #'
 #' @param effsize.type Type of effect size needed for *parametric* tests. The
 #'   argument can be `"biased"` (`"d"` for Cohen's *d*) or `"unbiased"`
 #'   (`"g"` Hedge's *g* for **t-test**). The default is `"g"`.
-#' @param effsize.noncentral Logical indicating whether to use non-central
-#'   *t*-distributions for computing the confidence interval for Cohen's *d*
-#'   or Hedge's *g* (Default: `TRUE`).
 #' @inheritParams expr_anova_parametric
 #' @inheritParams stats::t.test
 #' @inheritParams expr_template
 #'
-#' @importFrom dplyr select mutate_at matches vars starts_with ends_with
-#' @importFrom rlang !! enquo ensym
-#' @importFrom stats t.test na.omit qt pt uniroot
+#' @importFrom dplyr select rename_all recode mutate
+#' @importFrom rlang !! ensym new_formula exec
+#' @importFrom tidyr drop_na
+#' @importFrom stats t.test
+#' @importFrom effectsize cohens_d hedges_g
 #'
 #' @return Expression containing details from results of a two-sample test and
 #'   effect size plus confidence intervals.
@@ -33,8 +31,7 @@
 #'   is based on the standard deviation of the differences.
 #'
 #'   The computation of the confidence intervals defaults to a use of
-#'   non-central Student-*t* distributions (`effsize.noncentral = TRUE`);
-#'   otherwise a central distribution is used.
+#'   non-central Student-*t* distributions.
 #'
 #'   When computing confidence intervals the variance of the effect size *d* or
 #'   *g* is computed using the conversion formula reported in Cooper et al.
@@ -49,10 +46,7 @@
 #' set.seed(123)
 #' \donttest{
 #' # creating a smaller dataset
-#' msleep_short <- dplyr::filter(
-#'   .data = ggplot2::msleep,
-#'   vore %in% c("carni", "herbi")
-#' )
+#' msleep_short <- dplyr::filter(ggplot2::msleep, vore %in% c("carni", "herbi"))
 #'
 #' # with defaults
 #' statsExpressions::expr_t_parametric(
@@ -61,13 +55,12 @@
 #'   y = sleep_rem
 #' )
 #'
-#' # changing defaults
+#' # changing defaults (getting expression as output)
 #' statsExpressions::expr_t_parametric(
 #'   data = msleep_short,
 #'   x = vore,
 #'   y = sleep_rem,
 #'   var.equal = TRUE,
-#'   k = 2,
 #'   effsize.type = "d"
 #' )
 #' }
@@ -79,7 +72,6 @@ expr_t_parametric <- function(data,
                               y,
                               paired = FALSE,
                               effsize.type = "g",
-                              effsize.noncentral = TRUE,
                               conf.level = 0.95,
                               var.equal = FALSE,
                               k = 2,
@@ -93,7 +85,7 @@ expr_t_parametric <- function(data,
   data %<>%
     dplyr::select(.data = ., {{ x }}, {{ y }}) %>%
     dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }}))) %>%
-    tibble::as_tibble(x = .)
+    as_tibble(.)
 
   # properly removing NAs if it's a paired design
   if (isTRUE(paired)) {
@@ -106,7 +98,7 @@ expr_t_parametric <- function(data,
 
   # remove NAs listwise for between-subjects design
   if (isFALSE(paired)) {
-    data %<>% tidyr::drop_na(data = .)
+    data %<>% tidyr::drop_na(.)
 
     # sample size
     sample_size <- nrow(data)
@@ -115,76 +107,74 @@ expr_t_parametric <- function(data,
 
   # deciding which effect size to use (Hedge's g or Cohen's d)
   if (effsize.type %in% c("unbiased", "g")) {
-    hedges.correction <- TRUE
-    effsize.text <- quote(widehat(italic("g")))
+    effsize.text <- quote(widehat(italic("g"))["Hedge"])
+    .f <- effectsize::hedges_g
   } else {
-    hedges.correction <- FALSE
-    effsize.text <- quote(widehat(italic("d")))
+    effsize.text <- quote(widehat(italic("d"))["Cohen"])
+    .f <- effectsize::cohens_d
   }
 
   # setting up the t-test model and getting its summary
-  tobject <-
-    stats::t.test(
+  stats_df <-
+    broomExtra::tidy(stats::t.test(
       formula = rlang::new_formula({{ y }}, {{ x }}),
       data = data,
       paired = paired,
       alternative = "two.sided",
       var.equal = var.equal,
       na.action = na.omit
-    )
-
-  # tidy dataframe from model object
-  stats_df <- broomExtra::tidy(tobject)
+    ))
 
   # effect size object
   effsize_df <-
-    effsize_t_parametric(
-      formula = rlang::new_formula({{ y }}, {{ x }}),
+    rlang::exec(
+      .fn = .f,
+      x = rlang::new_formula({{ y }}, {{ x }}),
       data = data,
+      correction = FALSE,
       paired = paired,
-      hedges.correction = hedges.correction,
-      conf.level = conf.level,
-      noncentral = effsize.noncentral,
-      var.equal = var.equal,
-      tobject = tobject
-    )
+      pooled_sd = var.equal,
+      ci = conf.level
+    ) %>%
+    broomExtra::easystats_to_tidy_names(.)
 
   # when paired samples t-test is run df is going to be integer
   # ditto for when variance is assumed to be equal
   k.df <- ifelse(isTRUE(paired) || isTRUE(var.equal), 0L, k)
+  statistic.text <-
+    if (isTRUE(paired) || isTRUE(var.equal)) {
+      quote(italic("t")["Student"])
+    } else {
+      quote(italic("t")["Welch"])
+    }
 
   # preparing subtitle
-  subtitle <-
-    expr_template(
-      no.parameters = 1L,
-      stat.title = stat.title,
-      stats.df = stats_df,
-      effsize.df = effsize_df,
-      statistic.text = quote(italic("t")),
-      effsize.text = effsize.text,
-      n = sample_size,
-      conf.level = conf.level,
-      k = k,
-      k.parameter = k.df,
-      n.text = n.text
-    )
-
-  # return the subtitle
-  return(subtitle)
+  expr_template(
+    no.parameters = 1L,
+    stat.title = stat.title,
+    stats.df = stats_df,
+    effsize.df = effsize_df,
+    statistic.text = statistic.text,
+    effsize.text = effsize.text,
+    n = sample_size,
+    conf.level = conf.level,
+    k = k,
+    k.parameter = k.df,
+    n.text = n.text
+  )
 }
 
 
 #' @title Making expression for Mann-Whitney *U*-test/Wilcoxon test results
-#' @author \href{https://github.com/IndrajeetPatil}{Indrajeet Patil}, Chuck Powell
+#' @name expr_t_nonparametric
 #'
 #' @inheritParams expr_anova_parametric
 #' @inheritParams expr_t_parametric
 #' @inheritParams t1way_ci
 #'
 #' @importFrom dplyr select
-#' @importFrom rlang !! enquo exec
+#' @importFrom rlang !! enquo exec new_formula
 #' @importFrom stats wilcox.test
-#' @importFrom psych corr.test
 #' @importFrom rcompanion wilcoxonR wilcoxonPairedR
 #'
 #' @details For the two independent samples case, the Mann-Whitney *U*-test is
@@ -201,7 +191,7 @@ expr_t_parametric <- function(data,
 #'   *Note:* The *stats::wilcox.test* function does not follow the
 #'   same convention as *stats::t.test*. The sign of the *V* test statistic
 #'   will always be positive since it is **the sum of the positive signed ranks**.
-#'   Therefore *V* will vary in magnitude but not significance based solely
+#'   Therefore, *V* will vary in magnitude but not significance based solely
 #'   on the order of the grouping variable. Consider manually
 #'   reordering your factor levels if appropriate as shown in the second example
 #'   below.
@@ -241,9 +231,7 @@ expr_t_parametric <- function(data,
 #'
 #' # The order of the grouping factor matters when computing *V*
 #' # Changing default alphabetical order manually
-#' msleep_short$vore <- factor(msleep_short$vore,
-#'   levels = c("herbi", "carni")
-#' )
+#' msleep_short$vore <- factor(msleep_short$vore, levels = c("herbi", "carni"))
 #'
 #' # note the change in the reported *V* value but the identical
 #' # value for *p* and the reversed effect size
@@ -254,6 +242,7 @@ expr_t_parametric <- function(data,
 #' )
 #'
 #' # -------------- within-subjects design ------------------------
+#'
 #' # using dataset included in the package
 #' statsExpressions::expr_t_nonparametric(
 #'   data = VR_dilemma,
@@ -263,7 +252,7 @@ expr_t_parametric <- function(data,
 #'   conf.level = 0.90,
 #'   conf.type = "perc",
 #'   nboot = 200,
-#'   k = 5
+#'   k = 4
 #' )
 #' }
 #' @export
@@ -288,7 +277,7 @@ expr_t_nonparametric <- function(data,
   data %<>%
     dplyr::select(.data = ., {{ x }}, {{ y }}) %>%
     dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }}))) %>%
-    tibble::as_tibble(x = .)
+    as_tibble(.)
 
   # properly removing NAs if it's a paired design
   if (isTRUE(paired)) {
@@ -298,7 +287,7 @@ expr_t_nonparametric <- function(data,
     sample_size <- length(unique(data$rowid))
     n.text <- quote(italic("n")["pairs"])
     .f <- rcompanion::wilcoxonPairedR
-    statistic.text <- quote("log"["e"](italic("V")))
+    statistic.text <- quote("log"["e"](italic("V")["Wilcoxon"]))
   }
 
   # remove NAs listwise for between-subjects design
@@ -309,7 +298,7 @@ expr_t_nonparametric <- function(data,
     sample_size <- nrow(data)
     n.text <- quote(italic("n")["obs"])
     .f <- rcompanion::wilcoxonR
-    statistic.text <- quote("log"["e"](italic("W")))
+    statistic.text <- quote("log"["e"](italic("W")["Wilcoxon"]))
   }
 
   # setting up the test and getting its summary
@@ -347,27 +336,22 @@ expr_t_nonparametric <- function(data,
   if (isTRUE(messages)) effsize_ci_message(nboot, conf.level)
 
   # preparing subtitle
-  subtitle <-
-    expr_template(
-      no.parameters = 0L,
-      stats.df = stats_df,
-      effsize.df = effsize_df,
-      stat.title = stat.title,
-      statistic.text = statistic.text,
-      effsize.text = quote(widehat(italic("r"))),
-      n = sample_size,
-      n.text = n.text,
-      conf.level = conf.level,
-      k = k
-    )
-
-  # return the subtitle
-  return(subtitle)
+  expr_template(
+    no.parameters = 0L,
+    stats.df = stats_df,
+    effsize.df = effsize_df,
+    stat.title = stat.title,
+    statistic.text = statistic.text,
+    effsize.text = quote(widehat(italic("r"))),
+    n = sample_size,
+    n.text = n.text,
+    conf.level = conf.level,
+    k = k
+  )
 }
 
 #' @title Expression containing results from a robust *t*-test
 #' @name expr_t_robust
-#' @author \href{https://github.com/IndrajeetPatil}{Indrajeet Patil}
 #'
 #' @references For more details, see-
 #' \url{https://indrajeetpatil.github.io/statsExpressions/articles/stats_details.html}
@@ -379,7 +363,6 @@ expr_t_nonparametric <- function(data,
 #' @importFrom dplyr select
 #' @importFrom rlang !! enquo
 #' @importFrom WRS2 yuen yuen.effect.ci
-#' @importFrom tibble tribble
 #'
 #' @examples
 #' \donttest{
@@ -399,7 +382,7 @@ expr_t_nonparametric <- function(data,
 #'   x = supp,
 #'   y = len,
 #'   nboot = 10,
-#'   k = 1,
+#'   k = 3,
 #'   tr = 0.2
 #' )
 #'
@@ -438,7 +421,7 @@ expr_t_robust <- function(data,
   data %<>%
     dplyr::select(.data = ., {{ x }}, {{ y }}) %>%
     dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }}))) %>%
-    tibble::as_tibble(x = .)
+    as_tibble(.)
 
   # ---------------------------- between-subjects design --------------------
 
@@ -462,9 +445,10 @@ expr_t_robust <- function(data,
 
     # effect size dataframe
     effsize_df <-
-      tibble::tribble(
-        ~estimate, ~conf.low, ~conf.high,
-        effsize_obj$effsize[[1]], effsize_obj$CI[[1]], effsize_obj$CI[[2]]
+      tibble(
+        estimate = effsize_obj$effsize[[1]],
+        conf.low = effsize_obj$CI[[1]],
+        conf.high = effsize_obj$CI[[2]]
       )
 
     # Yuen's test for trimmed means
@@ -477,9 +461,10 @@ expr_t_robust <- function(data,
 
     # tidying it up
     stats_df <-
-      tibble::tribble(
-        ~statistic, ~parameter, ~p.value,
-        stats_obj$test, stats_obj$df, stats_obj$p.value
+      tibble(
+        statistic = stats_obj$test[[1]],
+        parameter = stats_obj$df[[1]],
+        p.value = stats_obj$p.value[[1]]
       )
 
     # subtitle parameters
@@ -521,35 +506,32 @@ expr_t_robust <- function(data,
   if (isTRUE(messages)) effsize_ci_message(nboot, conf.level)
 
   # preparing subtitle
-  subtitle <-
-    expr_template(
-      no.parameters = 1L,
-      stats.df = stats_df,
-      effsize.df = effsize_df,
-      stat.title = stat.title,
-      statistic.text = quote(italic("t")),
-      effsize.text = quote(widehat(italic(xi))),
-      n = sample_size,
-      n.text = n.text,
-      conf.level = conf.level,
-      k = k,
-      k.parameter = k.parameter
-    )
-
-  # return the subtitle
-  return(subtitle)
+  expr_template(
+    no.parameters = 1L,
+    stats.df = stats_df,
+    effsize.df = effsize_df,
+    stat.title = stat.title,
+    statistic.text = quote(italic("t")["Yuen"]),
+    effsize.text = quote(widehat(italic(xi))),
+    n = sample_size,
+    n.text = n.text,
+    conf.level = conf.level,
+    k = k,
+    k.parameter = k.parameter
+  )
 }
 
 #' @title Making expression containing Bayesian *t*-test results
 #' @name expr_t_bayes
-#' @author \href{https://github.com/IndrajeetPatil}{Indrajeet Patil}
 #'
 #' @references For more details, see-
 #' \url{https://indrajeetpatil.github.io/statsExpressions/articles/stats_details.html}
 #'
+#' @importFrom tidyBF bf_ttest
+#'
 #' @inheritParams expr_t_parametric
 #' @inheritParams expr_anova_parametric
-#' @inheritParams bf_ttest
+#' @inheritParams tidyBF::bf_ttest
 #'
 #' @examples
 #' \donttest{
@@ -588,36 +570,14 @@ expr_t_bayes <- function(data,
                          paired = FALSE,
                          k = 2,
                          ...) {
-  # make sure both quoted and unquoted arguments are supported
-  c(x, y) %<-% c(rlang::ensym(x), rlang::ensym(y))
-
-  # creating a dataframe
-  data %<>%
-    dplyr::select(.data = ., {{ x }}, {{ y }}) %>%
-    dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }}))) %>%
-    tibble::as_tibble(.)
-
   # prepare subtitle
-  subtitle <-
-    bf_ttest(
-      data = data,
-      x = {{ x }},
-      y = {{ y }},
-      paired = paired,
-      bf.prior = bf.prior,
-      caption = NULL,
-      output = "h1",
-      k = k
-    )
-
-  # return the message
-  return(subtitle)
+  tidyBF::bf_ttest(
+    data = data,
+    x = {{ x }},
+    y = {{ y }},
+    paired = paired,
+    bf.prior = bf.prior,
+    output = "h1",
+    k = k
+  )
 }
-
-# aliases -----------------------------------------------------------------
-
-#' @rdname expr_t_nonparametric
-#' @aliases expr_t_nonparametric
-#' @export
-
-expr_mann_nonparametric <- expr_t_nonparametric
