@@ -35,7 +35,6 @@ ipmisc::`%$%`
 #' @importFrom ipmisc "%<-%"
 ipmisc::`%<-%`
 
-
 #' @export
 #' @importFrom rlang "%||%"
 rlang::`%||%`
@@ -45,9 +44,35 @@ rlang::`%||%`
 rlang::`%|%`
 
 #' @export
-#' @importFrom tibble tibble
-tibble::tibble
+#' @importFrom ipmisc tibble
+ipmisc::tibble
 
 #' @export
-#' @importFrom tibble as_tibble
-tibble::as_tibble
+#' @importFrom ipmisc as_tibble
+ipmisc::as_tibble
+
+# ----------------------- tidyBF -------------------------------------
+
+#' @export
+#' @importFrom tidyBF bf_contingency_tab
+tidyBF::bf_contingency_tab
+
+#' @export
+#' @importFrom tidyBF bf_ttest
+tidyBF::bf_ttest
+
+#' @export
+#' @importFrom tidyBF bf_meta
+tidyBF::bf_meta
+
+#' @export
+#' @importFrom tidyBF bf_corr_test
+tidyBF::bf_corr_test
+
+#' @export
+#' @importFrom tidyBF bf_oneway_anova
+tidyBF::bf_oneway_anova
+
+#' @export
+#' @importFrom tidyBF prior
+tidyBF::prior
