@@ -1,5 +1,3 @@
-context("expr_corr_test")
-
 # nonparametric ----------------------------------------------------------
 
 testthat::test_that(
@@ -123,17 +121,15 @@ testthat::test_that(
     # using function
     set.seed(123)
     using_function <-
-      suppressWarnings(statsExpressions::expr_corr_test(
+      statsExpressions::expr_corr_test(
         data = ggplot2::msleep,
-        x = "brainwt",
+        x = names(ggplot2::msleep)[10],
         y = "sleep_total",
         type = "r",
         k = 4,
         conf.level = .50,
-        conf.type = "basic",
-        nboot = 25,
         messages = TRUE
-      ))
+      )
 
     # expected
     expected <-
@@ -155,9 +151,9 @@ testthat::test_that(
           "-0.5696",
           ", CI"["50%"],
           " [",
-          "-0.6432",
+          "-0.6289",
           ", ",
-          "-0.4927",
+          "-0.5037",
           "]",
           ", ",
           italic("n")["pairs"],
@@ -182,14 +178,14 @@ testthat::test_that(
     # using function
     set.seed(123)
     using_function <-
-      suppressWarnings(statsExpressions::expr_corr_test(
+      statsExpressions::expr_corr_test(
         data = ggplot2::msleep,
-        x = "brainwt",
+        x = names(ggplot2::msleep)[10],
         y = sleep_rem,
         type = "bf",
         k = 3,
         messages = FALSE
-      ))
+      )
 
     # expected
     expected <-
