@@ -1,5 +1,3 @@
-context("expr_t_bayes")
-
 # between-subjects design -----------------------------------------------
 
 testthat::test_that(
@@ -117,7 +115,7 @@ testthat::test_that(
 
     # converting to long format
     df_bird %<>%
-      tibble::as_tibble(x = .) %>%
+      as_tibble(x = .) %>%
       tidyr::gather(
         data = .,
         key = "type",
